@@ -22,7 +22,7 @@ require Exporter;
 @ISA = qw(Exporter);
 @EXPORT_OK = qw(finddeps);
 
-$VERSION = '3.10';
+$VERSION = '3.11';
 
 use constant MAXINT => ~0;
 
@@ -78,7 +78,9 @@ named parameters:
 =item nowarnings
 
 Warnings about modules where we can't find their META.yml or Makefile.PL, and
-so can't divine their pre-requisites, will be suppressed;
+so can't divine their pre-requisites, will be suppressed. Other warnings may
+still be emitted though, such as those telling you about modules which have
+dodgy (but still understandable) metadata;
 
 =item fatalerrors
 
@@ -154,6 +156,8 @@ Adds suggested modules to the list of dependencies, if set to a true value.
 
 =back
 
+Order of arguments is not important.
+
 It returns a list of CPAN::FindDependencies::Dependency objects, whose
 useful methods are:
 
@@ -279,20 +283,30 @@ This module is also free-as-in-mason software.
 =cut
 
 my $default_mirror = 'https://cpan.metacpan.org/';
+my @valid_params = qw(
+    nowarnings
+    fatalerrors
+    perl
+    cachedir
+    maxdepth
+    mirror
+    usemakefilepl
+    recommended
+    suggested
+);
 
 sub finddeps {
     @net_log = ();
-    my($module, @args) = @_;
+    my $module = '';
+    my @args = @_;
 
     my $self = bless({ indices => [], mirrors => [], seen => {} }, __PACKAGE__);
 
     while(@args) {
-        my $optname = shift(@args);
-        my $optarg  = shift(@args);
-        if($optname ne 'mirror' ) {
-            $self->{$optname} = $optarg
-        } else {
-            my($mirror, $packages) = split(/,/, $optarg);
+        my $option = shift(@args);
+        # print STDERR "found argument $option. Remaining args [".join(', ', @args)."]\n";
+        if($option eq 'mirror') {
+            my($mirror, $packages) = split(/,/, shift(@args));
             $mirror = $default_mirror if($mirror eq 'DEFAULT');
             $mirror .= '/' unless($mirror =~ m{/$});
             $packages = "${mirror}modules/02packages.details.txt.gz"
@@ -304,6 +318,12 @@ sub finddeps {
                 mirror   => $mirror,
                 packages => $packages
             };
+        } elsif(grep { $_ eq $option } @valid_params) {
+            $self->{$option} = shift(@args);
+        } elsif(!$module) {
+            $module = $option
+        } else {
+            die("Can't look for dependencies for '$option', already looking for deps for '$module'\n");
         }
     }
     unless(@{$self->{mirrors}}) {
@@ -568,7 +588,12 @@ sub _getreqs {
         last if($meta_file);
     }
     if ($meta_file) {
-        my $meta_data = eval { CPAN::Meta->load_string($meta_file); };
+        my $meta_data = eval {
+            local $SIG{__WARN__} = sub {
+                warn(join("\n", "In $distfile, $_[0]", @_[1 .. $#_]));
+            };
+            CPAN::Meta->load_string($meta_file);
+        };
         if ($@ || !defined($meta_data)) {
             $self->_yell("$author/$distname: failed to parse metadata")
         } else {
